@@ -862,6 +862,11 @@ public:
   /// @param[in] Poller Used poller object.
   void releasePoller(EVPoller &&Poller) noexcept;
 
+  /// Close unused Fd in Pollers.
+  ///
+  /// @param[in] Fd The Fd to be deleted.
+  void close(__wasi_fd_t Fd) noexcept;
+
   /// Terminate the process normally. An exit code of 0 indicates successful
   /// termination of the program. The meanings of other values is dependent on
   /// the environment.
@@ -1201,6 +1206,7 @@ public:
   EVPoller &operator=(EVPoller &&) = default;
 
   using VPoller::clock;
+  using VPoller::close;
   using VPoller::error;
   using VPoller::prepare;
   using VPoller::reset;
@@ -1242,6 +1248,12 @@ public:
     }
   }
 
+  void close(__wasi_fd_t Fd) noexcept {
+    if (auto Node = env().getNodeOrNull(Fd); likely(!!Node)) {
+      VPoller::close(Node);
+    }
+  }
+
 private:
   Environ &env() noexcept { return static_cast<Environ &>(Ctx.get()); }
 };
@@ -1265,6 +1277,13 @@ Environ::acquirePoller(Span<__wasi_event_t> Events) noexcept {
   return Poller;
 }
 
+inline void Environ::close(__wasi_fd_t Fd) noexcept {
+  std::unique_lock Lock(PollerMutex);
+  for (auto &Poller : PollerPool) {
+    Poller.close(Fd);
+  }
+}
+
 inline void Environ::releasePoller(EVPoller &&Poller) noexcept {
   std::unique_lock Lock(PollerMutex);
   PollerPool.push_back(std::move(Poller));
