@@ -1598,6 +1598,11 @@ void Poller::clock(__wasi_clockid_t Clock, __wasi_timestamp_t Timeout,
   }
 }
 
+void Poller::close(const INode &Node) noexcept {
+  FdDatas.erase(Node.Fd);
+  OldFdDatas.erase(Node.Fd);
+}
+
 void Poller::read(const INode &Node, TriggerType Trigger,
                   __wasi_userdata_t UserData) noexcept {
   assuming(Events.size() < WasiEvents.size());
