@@ -12,7 +12,7 @@ WasiNNModule::WasiNNModule() : ModuleInstance("wasi_ephemeral_nn") {
   addHostFunc("init_execution_context",
               std::make_unique<WasiNNInitExecCtx>(Env));
   addHostFunc("set_input", std::make_unique<WasiNNSetInput>(Env));
-  addHostFunc("get_output", std::make_unique<WasiNNGetOuput>(Env));
+  addHostFunc("get_output", std::make_unique<WasiNNGetOutput>(Env));
   addHostFunc("compute", std::make_unique<WasiNNCompute>(Env));
 }
 
